cerebrust is a library for interfacing with NeuroSky devices over Bluetooth. It provides functionality to configure and connect to a NeuroSky device using Bluetooth, as well as to read and parse data packets from the data stream.
Re-exports
pub use comm::DataReader;pub use comm::Packet;pub use comm::PacketVariant;pub use device::DeviceConfig;
Modules
- comm
- Provides functionality to communicate with the NeuroSky device
using the RFCOMM protocol. It defines the
DataReaderstruct which reads data packets from the device and parses them into aPacketstruct. - device
- Provides functionality to configure and connect to a NeuroSky device using
bluetooth. It includes a
DeviceConfigstruct for specifying the bluetooth adapter, target device name, and RFCOMM channel, as well as methods for discovering and connecting to the target device.